TokenizationRepresentation
==========================

.. currentmodule:: pykeen.nn.node_piece

.. autoclass:: TokenizationRepresentation
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~TokenizationRepresentation.num_tokens

   .. rubric:: Methods Summary

   .. autosummary::

      ~TokenizationRepresentation.from_tokenizer
      ~TokenizationRepresentation.iter_extra_repr
      ~TokenizationRepresentation.save_assignment

   .. rubric:: Attributes Documentation

   .. autoattribute:: num_tokens

   .. rubric:: Methods Documentation

   .. automethod:: from_tokenizer
   .. automethod:: iter_extra_repr
   .. automethod:: save_assignment
